@@ -170,7 +170,7 @@ position the label above the widget, use "-labelPack => [-side => 'top']".
 package Tk::JBrowseEntry;
 
 use vars qw($VERSION);
-$VERSION = '4.61';
+$VERSION = '4.64';
 
 use Tk;
 use Carp;
@@ -285,6 +285,8 @@ sub Populate
 	$w->{-tabcomplete} = delete($args->{-tabcomplete})  if (defined($args->{-tabcomplete}));
 	$w->{-altbinding} = 0;  #NEXT 2 ADDED 20050112 TO SUPPORT ALTERNATE KEY-ACTION MODELS.
 	$w->{-altbinding} = delete($args->{-altbinding})  if (defined($args->{-altbinding}));
+	#NEXT LINE ADDED 20060429 TO SUPPORT OPTION FOR USER DELETION OF LISTBOX ITEMS.
+	$w->{-deleteitemsok} = delete($args->{-deleteitemsok})  if (defined($args->{-deleteitemsok}));
 #print STDERR "-altbinding=$w->{-altbinding}= w=$w=\n";
 #	unless (defined($w->{-noselecttext}))
 #	{
@@ -857,6 +859,7 @@ sub SetBindings
 		$w->LbCopySelection(0,'listbox.space');
 		$e->selectionRange(0,'end')  unless ($w->{-noselecttext} || !$e->index('end'));
 		$e->icursor('end');
+		$w->{'savefocus'} = $w->focusCurrent;  #ADDED 20060621 TO ALLOW JFILEDIALOG TO SET FOCUS TO ANOTHER WIDGET WHEN USER SELECTS VIA SPACEBAR.
 		Tk->break;
 	}
 	);
@@ -884,6 +887,8 @@ sub SetBindings
 		Tk->break;
 	}
 	);
+	$l->bind('<Delete>' => sub { $w->delete($w->LbIndex) })   #ADDED 20060429 TO SUPPORT OPTION FOR USER DELETION OF LISTBOX ITEMS.
+			if ($w->{-deleteitemsok});
 	$l->bind('<Key>' => [\&keyFn,$w,$e,$l,1]);  
 			#if $w->cget( "-state" ) eq "readonly";
 	$e->bind('<Key>' => [\&keyFn,$w,$e,$l]);
@@ -1033,7 +1038,6 @@ sub PopupChoices
 		#my $bd = $c->cget(-bd) + $c->cget(-highlightthickness);  #CHGD. TO NEXT 20050120.
 		my $bd = $c->cget(-bd);
 		my ($unitpixels, $ht, $x1, $ee, $width, $x2);
-#print "-os=$^O=\n";
 		if ($^O =~ /Win/i)
 		{
 			$y1 -= 3 - ($w->{-borderwidth} || 2);
@@ -1056,7 +1060,6 @@ sub PopupChoices
 			$unitpixels = $e->height - (2*$w->cget(-highlightthickness));
 			$unitpixels += 1;
 			$ht = ($wheight * $unitpixels) + (2 * $bd) + 6;
-#print "-ht=$ht= wheight=$wheight= up=$unitpixels= bd=$bd= eht=".$e->height."= ht=".$w->cget(-highlightthickness)."= \n";
 			$ee = $w->Subwidget("frame");
 			$x1 = $ee->rootx;
 			$x2 = $a->rootx + $a->width;
@@ -1214,7 +1217,8 @@ sub LbFindSelection
 		$index = 0  if ($index > $#listsels);
 		#if ($listsels[$index] =~ /^$srchval/i)
 		#CHGD. TO NEXT 20030531 PER PATCH BY FRANK HERRMANN.
-		if (defined $srchval && $listsels[$index] =~ /^$srchval/i)
+#		if (defined $srchval && $listsels[$index] =~ /^$srchval/i) #CHGD TO NEXT 20060429 TO PREVENT TK-ERROR ON "("!
+		if (defined $srchval && $listsels[$index] =~ /^\Q$srchval\E/i)
 		{
 			$l->selectionClear('0','end');
 			$l->activate($index);
@@ -1537,7 +1541,6 @@ sub _set_edit_state
 				-takefocus => (1 & $w->{takefocus}), 
 				-highlightcolor => $framehlcolor);
 	}
-#print "-???- tfg=$w->{-textforeground}=\n";
 	$entry->configure( -background => $w->{-textbackground})  if ($w->{-textbackground});
 	$entry->configure( -foreground => $w->{-textforeground})  if ($w->{-textforeground});
 	unless ($w->Subwidget("slistbox")->size > 0)
